@@ -15,7 +15,6 @@
 #include <sys/ioctl.h>
 #include <asm/ioctl.h>
 #include <sys/mman.h>
-#include <sys/utsname.h>
 
 /*----------------------------------------------------------------------------*/
 #include "softPwm.h"
@@ -523,12 +522,22 @@ static int _analogRead (int pin)
 
 	/* wiringPi ADC number = pin 25, pin 29 */
 	switch (pin) {
-	case	3:	case	25:
+#if defined(ARDUINO)
+	/* To work with physical analog channel numbering */
+	case	2:	case	25:
 		pin = 0;
 	break;
-	case	2:	case	29:
+	case	0:	case	29:
 		pin = 1;
 	break;
+#else
+	case	0:	case	25:
+		pin = 0;
+	break;
+	case	1:	case	29:
+		pin = 1;
+	break;
+#endif
 	default:
 		return	0;
 	}
