@@ -26,6 +26,7 @@
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <sys/ioctl.h>
+#include <sys/utsname.h>
 #include <asm/ioctl.h>
 
 /*----------------------------------------------------------------------------*/
@@ -57,7 +58,7 @@ const char *piModelNames [16] =
 	"ODROID-C2",
 	"ODROID-XU3/XU4",
 	"ODROID-N1",
-	"ODROID-N2",
+	"ODROID-N2/N2Plus",
 	"ODROID-C4",
 };
 
@@ -134,6 +135,14 @@ int wiringPiSetuped     = FALSE ;
 // ODROID Wiring Library
 struct libodroid	libwiring;
 
+// Current kernel version
+struct kernelVersionStruct *kernelVersion = &(struct kernelVersionStruct) {
+	.major = 0,
+	.minor = 0,
+	.revision = 0,
+	.release = ""
+};
+
 /*----------------------------------------------------------------------------*/
 //
 // Return true/false if the supplied module is loaded
@@ -252,6 +261,106 @@ void setUsingGpiomem(const unsigned int value)
 	libwiring.usingGpiomem = value;
 }
 
+/*----------------------------------------------------------------------------*/
+/*
+ * setKernelVersion:
+ *	It sets current operating kernel version to the global struct variable.
+ */
+/*----------------------------------------------------------------------------*/
+void setKernelVersion() {
+	struct utsname uname_buf;
+
+	char* buf;
+	char* delimiter = ".";
+	int i;
+
+	int kernelNumbers[3] = { 0, };
+	int revLastIndex = 0;
+	char revisionStringBuf[8];
+
+	uname(&uname_buf);
+	memcpy(kernelVersion->release, uname_buf.release, strlen(uname_buf.release));
+
+	buf = strtok(uname_buf.release, delimiter);
+	for (i = 0; i < 2; i++) {
+		switch (i) {
+		case 0:
+			kernelNumbers[i] = atoi(buf);
+			buf = strtok(NULL, delimiter);
+		break;
+		case 1:
+			kernelNumbers[i] = atoi(buf);
+			buf = strtok(NULL, "\n");
+		break;
+		}
+	}
+
+	if (isdigit(buf[0])) {
+		for (i = 0; i < (int) strlen(buf); i++) {
+			if (!isdigit(buf[i])) {
+				revLastIndex = i - 1;
+				break;
+			}
+		}
+
+		memcpy(revisionStringBuf, buf, revLastIndex + 1);
+
+		revisionStringBuf[revLastIndex + 1] = '\n';
+		kernelNumbers[2] = atoi(revisionStringBuf);
+	} else {
+		kernelNumbers[2] = 0;
+	}
+
+	kernelVersion->major = kernelNumbers[0];
+	kernelVersion->minor = kernelNumbers[1];
+	kernelVersion->revision = kernelNumbers[2];
+}
+
+/*----------------------------------------------------------------------------*/
+/*
+ * cmpKernelVersion:
+ *	It compares kernel version between the current one and the passed in
+ *	numbers. If the current one is bigger than the arguments, it returns
+ *	true, or it returns false.
+ */
+/*----------------------------------------------------------------------------*/
+char cmpKernelVersion(int num, ...) {
+	va_list valist;
+	int versionCompareTo[3] = { 0, };
+	int i;
+	char ret = FALSE;
+
+	va_start(valist, num);
+
+	for (i = 0; i < num; i++) {
+		versionCompareTo[i] = va_arg(valist, int);
+	}
+
+	switch (num) {
+	case KERN_NUM_TO_MAJOR:
+		if (kernelVersion->major >= versionCompareTo[0])
+			ret = TRUE;
+	break;
+	case KERN_NUM_TO_MINOR:
+		if (kernelVersion->major > versionCompareTo[0] ||
+		    kernelVersion->minor >= versionCompareTo[1])
+			ret = TRUE;
+	break;
+	case KERN_NUM_TO_REVISION:
+		if (kernelVersion->major > versionCompareTo[0] ||
+		    kernelVersion->minor > versionCompareTo[1] ||
+		    kernelVersion->revision >= versionCompareTo[2])
+			ret = TRUE;
+	break;
+	default:
+		msg(MSG_ERR, "%s: Unknown fixed argument %d. \n", __func__, num);
+	break;
+	}
+
+	va_end(valist);
+	return ret;
+}
+
 /*----------------------------------------------------------------------------*/
 int getModelFromCpuinfo(char *line, FILE *cpuFd) {
 	char *model;
@@ -396,6 +505,7 @@ int piGpioLayout (void) {
 	if (wiringPiDebug)
 		printf("BoardRev: Returning revision: %d\n", libwiring.rev);
 
+	setKernelVersion();
 	return libwiring.rev;
 }
 
